import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Modal, Button, notification } from 'antd'
import { SnippetsOutlined } from '@ant-design/icons'

import MenuUtils from '@/utils/utils-custom.js'
import asyncComponent from '@/utils/asyncComponent'
// import './index.scss'

const PasteForm = asyncComponent(() => import('@/templates/zshare/pasteform'))

class PasteController extends Component {
  static propTpyes = {
    insert: PropTypes.func
  }

  state = {
    visible: false
  }

  resetconfig = (item, uuids = {}) => {
    let appType = sessionStorage.getItem('appType')
    
    if (item.type === 'tabs') {
      uuids[item.uuid] = MenuUtils.getuuid()
      item.uuid = uuids[item.uuid]
      item.setting.name = item.setting.name + MenuUtils.getSignName()
      item.name = item.setting.name

      item.subtabs.forEach(tab => {
        uuids[tab.uuid] = MenuUtils.getuuid()
        tab.uuid = uuids[tab.uuid]

        if (appType !== 'mob') {
          tab.components = tab.components.filter(cell => cell.type !== 'menubar')
        }

        tab.components = tab.components.map(cell => {
          cell = this.resetconfig(cell, uuids)
          return cell
        })
      })
    } else if (item.type === 'group') {
      uuids[item.uuid] = MenuUtils.getuuid()
      item.uuid = uuids[item.uuid]
      item.setting.name = item.setting.name + MenuUtils.getSignName()
      item.name = item.setting.name

      item.components = item.components.map(cell => {
        cell = MenuUtils.resetComponentConfig(cell, uuids)
        return cell
      })
    } else {
      item = MenuUtils.resetComponentConfig(item, uuids)
    }

    return item
  }

  pasteSubmit = () => {
    let appType = sessionStorage.getItem('appType')
    let options = ['tabs', 'timeline', 'datacard', 'propcard', 'mainsearch', 'simpleform', 'stepform', 'tabform', 'balcony', 'group', 'normaltable', 'tablecard', 'line', 'bar', 'pie', 'dashboard', 'scatter']

    if (appType === 'mob') {
      options.push('menubar', 'topbar')
    } else {
      options.push('editable')
    }

    this.pasteFormRef.handleConfirm().then(res => {
      if (!options.includes(res.copyType)) {
        notification.warning({
          top: 92,
          message: '配置信息格式错误！',
          duration: 5
        })
        return
      }

      res = this.resetconfig(res)

      // delete res.copyType
      
      this.props.insert(res)

      this.setState({visible: false})
    })
  }

  render() {
    const { visible } = this.state

    return (
      <div className="mk-view-paste" style={{display: 'inline-block'}}>
        <Button style={{borderColor: '#40a9ff', color: '#40a9ff'}} onClick={() => {this.setState({visible: true})}}><SnippetsOutlined />粘贴</Button>
        <Modal
          title="粘贴"
          visible={visible}
          width={600}
          maskClosable={false}
          onOk={this.pasteSubmit}
          onCancel={() => {this.setState({visible: false})}}
          destroyOnClose
        >
          <PasteForm wrappedComponentRef={(inst) => this.pasteFormRef = inst} inputSubmit={this.pasteSubmit}/>
        </Modal>
      </div>
    )
  }
}

export default PasteController